==> nextcloud-app-notes-3.1.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/zh_CN.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "笔记",
    "The last viewed note cannot be accessed. " : "不能访问上次查看的笔记。",
    "The notes folder is not accessible: %s" : "笔记文件夹无法访问：%s",
    "New note" : "新建笔记",
    "Encryption Error" : "加密错误",
    "Error" : "错误",
    "Distraction-free notes and writing" : "无干扰的笔记和写作",
    "The Notes app is a distraction free notes taking app. It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [RESTful API](https://github.com/nextcloud/notes/wiki/API-0.2) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes) and [iOS](https://github.com/owncloud/notes-iOS-App) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "笔记应用是一个无干扰的记笔记应用。它提供易于组织的分类，并支持使用[Markdown](https://en.wikipedia.org/wiki/Markdown)语法的文本格式化。笔记在您的Nextcloud中保存为文件，所以您可以使用所有客户端查看和编辑它们。而且，有一个单独的[RESTful API](https://github.com/nextcloud/notes/wiki/API-0.2)用来与第三方应用（当前， [Android](https://github.com/stefan-niedermann/nextcloud-notes)和[iOS](https://github.com/owncloud/notes-iOS-App)的笔记应用可用来方便地访问您的Nextcloud笔记）更好地集成。更多的特性包括把笔记标记为收藏。",
    "Settings" : "设置",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
    "Folder to store your notes" : "保存您的笔记的文件夹",
    "path to notes" : "笔记的路径",
    "File extension for new notes" : "新笔记的文件扩展名",
    "All notes" : "所有笔记",
    "Categories" : "分类",
    "No search result for “{search}” in {category}" : "在 {category} 中没有关于 “{search}”的搜索结果",
    "No search result for “{search}”" : "没有关于“{search}”的搜索结果",
    "Loading …" : "正在加载…",
    "Search result for “{search}” in {category}" : "在{category}中搜索 “{search}”的结果",
    "Search result for “{search}”" : "搜索 “{search}”的结果",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本周",
    "Last week" : "上周",
    "This month" : "本月",
    "Last month" : "上月",
    "Delete note" : "删除笔记",
    "Deleted {title}" : "已删除 {title}",
    "Remove from favorites" : "从收藏中移除",
    "Add to favorites" : "添加到收藏",
    "Empty note" : "空笔记",
    "Write …" : "编写 ...",
    "Details" : "详细信息",
    "Preview" : "预览",
    "Edit" : "编辑",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Save failed. Click to retry." : "保存失败。点击以重试。",
    "Set category" : "设置分类",
    "Category" : "分类",
    "Uncategorized" : "未分类",
    "Click here to save manually" : "点击这里以手动保存",
    "Saving failed!" : "保存失败！",
    "Last modified: {date}" : "上一次更改：{date}",
    "Note has unsaved changes" : "笔记有未保存的更改",
    "Subcategory" : "子类别",
    "_%n word_::_%n words_" : ["%n 个字"],
    "Write down your thoughts without any distractions." : "心无旁骛地写下您的想法。",
    "Use Markdown markups to style your text." : "使用Markdown标注来格式化您的文本。",
    "Organize your notes in categories." : "在分类中组织您的笔记。",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "在您的手机中安装此应用以随时随地访问您的笔记。",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在应用导航栏中点击“{newnote}”开始做笔记",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "您可以创建子类别，在父类别和子类别之间使用 “/” 作为分隔符，例如 “{parent}/{sub}”。",
    "Please chose a valid path in {label} (bottom left corner)." : "请在 {label}（左下角）中选择一个有效路径。",
    "See JavaScript console for details." : "请至JavaScript控制台查看详细信息。",
    "Saving the note has failed due to insufficient storage." : "由于存储空间不足，无法保存笔记。",
    "Updating settings has failed." : "更新设置失败。",
    "Fetching notes has failed." : "获取笔记失败。",
    "Fetching note {id} has failed." : "获取笔记 {id} 失败。",
    "Creating new note has failed." : "创建新笔记失败。",
    "Updating note {id} has failed." : "更新笔记 {id} 失败。",
    "Deleting note {id} has failed." : "删除笔记 {id} 失败。",
    "Toggling favorite for note {id} has failed." : "将笔记 {id} 设为收藏失败。",
    "Updating the note's category has failed. Is the target directory writable?" : "无法更新存储笔记的文件夹。请检查目标文件夹是否可写。",
    "Updating the category for note {id} has failed." : "更新笔记 {id} 的分类失败。",
    "Development Mode" : "开发模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "笔记应用似乎是从一个开发来源安装的。请改从官方<a href=\"%1$s\">Nextcloud应用商店</a>来安装它。如果您想自己笔记应用，请参考<a href=\"%2$s\">开发者指南</a>。"
},
"nplurals=1; plural=0;");

==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/zh_CN.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "笔记",
    "The last viewed note cannot be accessed. " : "不能访问上次查看的笔记。",
    "The notes folder is not accessible: %s" : "笔记文件夹无法访问：%s",
    "Error" : "错误",
    "New note" : "新建笔记",
    "Distraction-free notes and writing" : "无干扰的笔记和写作",
    "Settings" : "设置",
    "Deleted {title}" : "已删除 {title}",
    "Deleted {number} notes" : "已删除 {number} 条笔记",
    "Undo Delete" : "撤销删除",
    "Please chose a valid path in {label} (bottom left corner)." : "请在 {label}（左下角）中选择一个有效路径。",
    "There are unsaved notes. Leaving the page will discard all changes!" : "有未保存的记录，离开页面将丢弃所有更改！",
    "Folder to store your notes" : "保存您的笔记的文件夹",
    "path to notes" : "笔记的路径",
    "File extension for new notes" : "新笔记的文件扩展名",
    "All notes" : "所有笔记",
    "Categories" : "分类",
    "No search result for “{search}” in {category}" : "在 {category} 中没有关于 “{search}”的搜索结果",
    "No search result for “{search}”" : "没有关于“{search}”的搜索结果",
    "Loading …" : "正在加载…",
    "Search result for “{search}” in {category}" : "在{category}中搜索 “{search}”的结果",
    "Search result for “{search}”" : "搜索 “{search}”的结果",
    "Today" : "今天",
    "Yesterday" : "昨天",
    "This week" : "本周",
    "Last week" : "上周",
    "This month" : "本月",
    "Last month" : "上月",
    "Rename" : "重命名",
    "Delete note" : "删除笔记",
    "Remove from favorites" : "从收藏夹移除",
    "Add to favorites" : "添加到收藏夹",
    "Error during preparing note for deletion." : "准备删除笔记时出错。",
    "Empty note" : "空笔记",
    "Write …" : "编写 ...",
    "Details" : "详细信息",
    "Preview" : "预览",
    "Edit" : "编辑",
    "Exit full screen" : "退出全屏",
    "Full screen" : "全屏",
    "Save failed. Click to retry." : "保存失败。点击以重试。",
    "Set category" : "设置分类",
    "Category" : "分类",
    "Uncategorized" : "未分类",
    "Click here to save manually" : "点击这里以手动保存",
    "Saving failed!" : "保存失败！",
    "Last modified: {date}" : "上一次更改：{date}",
    "Note has unsaved changes" : "笔记有未保存的更改",
    "Subcategory" : "子类别",
    "_%n word_::_%n words_" : ["%n 个字"],
    "Write down your thoughts without any distractions." : "心无旁骛地写下您的想法。",
    "Use Markdown markups to style your text." : "使用Markdown标注来格式化您的文本。",
    "Organize your notes in categories." : "在分类中组织您的笔记。",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "在您的手机中安装此应用以随时随地访问您的笔记。",
    "Android app" : "安卓应用",
    "iOS app" : "iOS 应用",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "在应用导航栏中点击“{newnote}”开始做笔记",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "您可以创建子类别，在父类别和子类别之间使用 “/” 作为分隔符，例如 “{parent}/{sub}”。",
    "See JavaScript console and server log for details." : "有关详情请参见 JavaScript 控制台和服务器日志。",
    "Saving the note has failed due to insufficient storage." : "由于存储空间不足，无法保存笔记。",
    "Updating settings has failed." : "更新设置失败。",
    "Fetching notes has failed." : "获取笔记失败。",
    "Fetching note {id} has failed." : "获取笔记 {id} 失败。",
    "Creating new note has failed." : "创建新笔记失败。",
    "Updating note {id} has failed." : "更新笔记 {id} 失败。",
    "Undo delete has failed for note {title}." : "笔记 {title} 的撤消删除失败。",
    "Deleting note {id} has failed." : "删除笔记 {id} 失败。",
    "Toggling favorite for note {id} has failed." : "将笔记 {id} 设为收藏失败。",
    "Updating the note's category has failed. Is the target directory writable?" : "无法更新存储笔记的文件夹。请检查目标文件夹是否可写。",
    "Updating the category for note {id} has failed." : "更新笔记 {id} 的分类失败。",
    "Development Mode" : "开发模式",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "笔记应用似乎是从一个开发来源安装的。请改从官方<a href=\"%1$s\">Nextcloud应用商店</a>来安装它。如果您想自己笔记应用，请参考<a href=\"%2$s\">开发者指南</a>。"
},
"nplurals=1; plural=0;");
